@@ -63,10 +63,12 @@ class ModelExplanationData:
 class ErrorAnalysisData:
     maxDepth: int
     numLeaves: int
+    minChildSamples: int
     tree: list
     matrix: list
     tree_features: List[str]
     matrix_features: List[str]
+    metric: str
 
 
 class CausalMetric:
